﻿Imports System.Collections.ObjectModel
Imports MindFusion
Imports MindFusion.Charting.WinForms
Imports MindFusion.Charting
Imports MindFusion.Charting.Gauges
Imports MindFusion.Charting.Components

Imports Brush = MindFusion.Drawing.Brush
Imports SolidBrush = MindFusion.Drawing.SolidBrush
Imports Text = MindFusion.Gauges.Text
Imports Length = MindFusion.Gauges.Length
Imports Pointer = MindFusion.Gauges.Pointer

Public Class MainForm

	Private Sub Form1_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load
		Dim builder = New LayoutBuilder(dashboard)

		dashboard.LayoutPanel.Children.Add(New TextComponent() With {.HorizontalAlignment = LayoutAlignment.Center, .Text = "What devices and web apps are people using?"})

		' build title as a stack of text components
		Dim nameStack = New StackPanel() With {.Orientation = MindFusion.Charting.Components.Orientation.Horizontal, .HorizontalAlignment = LayoutAlignment.Center}

		dashboard.LayoutPanel.Children.Add(nameStack)
		AddToStack(nameStack, "Yahoo", New SolidBrush(Color.Purple)).HorizontalAlignment = LayoutAlignment.Center

		AddToStack(nameStack, " vs", Nothing)

		AddToStack(nameStack, " G", New SolidBrush(Color.FromArgb(66, 133, 244)))
		AddToStack(nameStack, "o", New SolidBrush(Color.FromArgb(219, 68, 55)))
		AddToStack(nameStack, "o", New SolidBrush(Color.FromArgb(244, 180, 0)))
		AddToStack(nameStack, "g", New SolidBrush(Color.FromArgb(66, 133, 244)))
		AddToStack(nameStack, "l", New SolidBrush(Color.FromArgb(15, 157, 88)))
		AddToStack(nameStack, "e", New SolidBrush(Color.FromArgb(219, 68, 55)))

		AddToStack(nameStack, " vs", Nothing)

		AddToStack(nameStack, " Facebook", New SolidBrush(Color.FromArgb(59, 89, 152)))

		' create bar-chart axis renderers
		Dim barPlotYAxis = New Axis()
		barPlotYAxis.MinValue = 0
		barPlotYAxis.MaxValue = 1010
		barPlotYAxis.Interval = 100
		barPlotYAxis.Title = "Millions of Users"

		Dim barPlotXAxis = New Axis()
		barPlotXAxis.MaxValue = 10
		barPlotXAxis.MinValue = 1
		barPlotXAxis.Interval = 1
		barPlotXAxis.Title = "Time of Day"

		Dim barPlotYAxisRenderer = New YAxisRenderer(barPlotYAxis)
		Dim barPlotXAxisRenderer = New XAxisRenderer(barPlotXAxis)

		' create bar-chart plot
		Dim barPlot As New Plot2D()
		barPlotXAxisRenderer.LabelsSource = barPlot
		barPlotXAxisRenderer.ShowCoordinates = False

		' create sample data
		Dim smartphones = GenerateSeries(1, 24, 1)
		smartphones.Labels = New List(Of String)()
		For i As Integer = 0 To 23
			smartphones.Labels.Add(String.Format("{0}:{1}" & vbLf & "{2}", If((i \ 13 = 0), i.ToString("D" & 2), (i Mod 12).ToString("D" & 2)), (0).ToString("D" & 2), If((i \ 13 = 0), "AM", "PM")))
		Next
		smartphones.SupportedLabels = LabelKinds.XAxisLabel
		smartphones.Title = "Smartphones"

		Dim tablets = GenerateSeries(1, 24, 1)
		tablets.Title = "Tablets"

		Dim computers = GenerateSeries(1, 24, 1)
		computers.Title = "Computers"

		' render the data series as bars
		Dim barRenderer = New BarRenderer(New ObservableCollection(Of Series)() From { _
		 smartphones, _
		 tablets, _
		 computers _
		})

		barRenderer.SeriesStyle = New PerSeriesStyle() With {
		  .Fills = New List(Of Brush)() From {
		  New SolidBrush(Color.FromArgb(102, 154, 204)),
		  New SolidBrush(Color.FromArgb(0, 52, 102)),
		  New SolidBrush(Color.FromArgb(206, 0, 0))
		 },
		  .Strokes = New List(Of Brush)() From {
		  New SolidBrush(Color.FromArgb(102, 154, 204)),
		  New SolidBrush(Color.FromArgb(0, 52, 102)),
		  New SolidBrush(Color.FromArgb(206, 0, 0))
		 }
		}

		barPlot.YAxis = barPlotYAxis
		barPlot.XAxis = barPlotXAxis
		barPlot.GridType = GridType.Horizontal
		barPlot.GridColor1 = Color.FromArgb(218, 218, 218)

		barRenderer.YAxis = barPlotYAxis

		' create line plot
		Dim linePlot As New Plot2D()
		linePlot.Background = New SolidBrush(Color.LightGray)
		linePlot.GridType = GridType.Horizontal
		linePlot.GridColor1 = Color.FromArgb(218, 218, 218)

		' create sample data
		Dim yahooSeries = New Series2D(New List(Of Double)() From { _
		 0, _
		 1, _
		 2, _
		 3, _
		 4, _
		 5, _
		 6, _
		 7, _
		 8, _
		 9, _
		 10, _
		 11, _
		 12, _
		 13, _
		 14, _
		 15, _
		 16, _
		 17, _
		 18, _
		 19, _
		 20, _
		 21, _
		 22, _
		 23, _
		 24, _
		 25, _
		 26, _
		 27, _
		 28, _
		 29, _
		 30, _
		 31, _
		 32, _
		 33, _
		 34, _
		 35, _
		 36 _
		}, New List(Of Double)() From { _
		 40000, _
		 38000, _
		 39000, _
		 39000, _
		 41000, _
		 37500, _
		 35300, _
		 37500, _
		 34500, _
		 37800, _
		 39000, _
		 37800, _
		 37800, _
		 34500, _
		 41500, _
		 44000, _
		 48000, _
		 43000, _
		 44000, _
		 49000, _
		 37500, _
		 42500, _
		 43500, _
		 43500, _
		 42000, _
		 42200, _
		 43500, _
		 43200, _
		 40500, _
		 40500, _
		 39000, _
		 40500, _
		 38000, _
		 42000, _
		 39000, _
		 38000, _
		 37000 _
		}, New List(Of String)() From { _
		 "jun 07", _
		 " ", _
		 " ", _
		 " ", _
		 "oct 07", _
		 " ", _
		 " ", _
		 " ", _
		 "feb 08", _
		 " ", _
		 " ", _
		 " ", _
		 "jun 08", _
		 " ", _
		 " ", _
		 " ", _
		 "oct 08", _
		 " ", _
		 " ", _
		 " ", _
		 "feb 09", _
		 " ", _
		 " ", _
		 " ", _
		 "jun 09", _
		 " ", _
		 " ", _
		 " ", _
		 "oct 09", _
		 " ", _
		 " ", _
		 " ", _
		 "feb 10", _
		 " ", _
		 " ", _
		 " ", _
		 "jun 10" _
		}) With {.Title = "Yahoo"}
		yahooSeries.SupportedLabels = LabelKinds.XAxisLabel

		Dim googleSeries = New Series2D(New List(Of Double)() From { _
		 0, _
		 1, _
		 2, _
		 3, _
		 4, _
		 5, _
		 6, _
		 7, _
		 8, _
		 9, _
		 10, _
		 11, _
		 12, _
		 13, _
		 14, _
		 15, _
		 16, _
		 17, _
		 18, _
		 19, _
		 20, _
		 21, _
		 22, _
		 23, _
		 24, _
		 25, _
		 26, _
		 27, _
		 28, _
		 29, _
		 30, _
		 31, _
		 32, _
		 33, _
		 34, _
		 35, _
		 36 _
		}, New List(Of Double)() From { _
		 11500, _
		 12500, _
		 12600, _
		 13500, _
		 13400, _
		 14500, _
		 14500, _
		 16500, _
		 16500, _
		 16500, _
		 16600, _
		 16600, _
		 17000, _
		 17000, _
		 17100, _
		 19000, _
		 19000, _
		 18500, _
		 18500, _
		 21200, _
		 20700, _
		 26500, _
		 28500, _
		 34500, _
		 33500, _
		 36500, _
		 36500, _
		 34500, _
		 37000, _
		 38500, _
		 41000, _
		 39000, _
		 40500, _
		 40000, _
		 40500, _
		 41000, _
		 41000 _
		}, Nothing) With {.Title = "Google"}

		Dim facebookSeries = New Series2D(New List(Of Double)() From { _
		 0, _
		 1, _
		 2, _
		 3, _
		 4, _
		 5, _
		 6, _
		 7, _
		 8, _
		 9, _
		 10, _
		 11, _
		 12, _
		 13, _
		 14, _
		 15, _
		 16, _
		 17, _
		 18, _
		 19, _
		 20, _
		 21, _
		 22, _
		 23, _
		 24, _
		 25, _
		 26, _
		 27, _
		 28, _
		 29, _
		 30, _
		 31, _
		 32, _
		 33, _
		 34, _
		 35, _
		 36 _
		}, New List(Of Double)() From { _
		 5000, _
		 6150, _
		 6100, _
		 5000, _
		 6050, _
		 6100, _
		 6100, _
		 6150, _
		 6100, _
		 5150, _
		 6200, _
		 6200, _
		 8000, _
		 8000, _
		 9500, _
		 10500, _
		 10500, _
		 11500, _
		 12000, _
		 10500, _
		 12000, _
		 16000, _
		 16500, _
		 17000, _
		 17500, _
		 20000, _
		 26000, _
		 27500, _
		 31500, _
		 30000, _
		 31500, _
		 32500, _
		 36000, _
		 37500, _
		 39000, _
		 41000, _
		 42000 _
		}, Nothing) With { _
		  .Title = "Facebook" _
		}

		' define axis ranges
		Dim yAxis = New Axis()
		yAxis.MinValue = 0
		yAxis.MaxValue = 55000
		yAxis.Interval = 5000
		yAxis.Title = "Millions of Minutes"

		Dim xAxis = New Axis()
		xAxis.MinValue = 0
		xAxis.MaxValue = 36
		xAxis.Interval = 1
		xAxis.Title = " "

		linePlot.XAxis = xAxis
		linePlot.YAxis = yAxis

		' render sample data as line-chart
		Dim lineRenderer = New LineRenderer(New ObservableCollection(Of Series)() From { _
		 googleSeries, _
		 yahooSeries, _
		 facebookSeries _
		})
		lineRenderer.YAxis = yAxis

		Dim googleBrush = New MindFusion.Drawing.LinearGradientBrush(Color.FromArgb(66, 133, 244), Color.FromArgb(244, 180, 0))
		googleBrush.InterpolationColors = New System.Drawing.Drawing2D.ColorBlend(4)
		googleBrush.InterpolationColors.Colors = New Color() {Color.FromArgb(66, 133, 244), Color.FromArgb(244, 180, 0), Color.FromArgb(219, 68, 55), Color.FromArgb(66, 133, 244)}
		googleBrush.InterpolationColors.Positions = New Single() {0.0F, 0.33F, 0.66F, 1.0F}

		lineRenderer.SeriesStyle = New MixedSeriesStyle() With { _
		  .Strokes = New List(Of List(Of Brush))() From { _
		  New List(Of Brush)() From { _
		   New SolidBrush(Color.FromArgb(66, 133, 244)), _
		   New SolidBrush(Color.FromArgb(219, 68, 55)), _
		   New SolidBrush(Color.FromArgb(244, 180, 0)), _
		   New SolidBrush(Color.FromArgb(66, 133, 244)), _
		   New SolidBrush(Color.FromArgb(15, 157, 88)), _
		   New SolidBrush(Color.FromArgb(219, 68, 55)) _
		  }, _
		  New List(Of Brush)() From { _
		   New SolidBrush(Color.Purple) _
		  }, _
		  New List(Of Brush)() From { _
		   New SolidBrush(Color.FromArgb(59, 89, 152)), _
		   New SolidBrush(Color.FromArgb(242, 242, 242)) _
		  } _
		 }, _
		  .UniformStrokeThickness = 5, _
		  .CommonFills = New List(Of Brush)() From { _
		  googleBrush, _
		  New SolidBrush(Color.Purple), _
		  New MindFusion.Drawing.LinearGradientBrush(Color.FromArgb(59, 89, 152), Color.FromArgb(242, 242, 242)) _
		 } _
		}

		' show Y axis
		Dim linePlotYRenderer = New YAxisRenderer(yAxis)
		linePlotYRenderer.LabelsSource = linePlot

		' show X axis
		Dim linePlotXRenderer = New XAxisRenderer(xAxis)
		linePlotXRenderer.LabelsSource = linePlot
		linePlotXRenderer.ShowCoordinates = False
		linePlotXRenderer.ShowTicks = False
		linePlotXRenderer.ShowSeriesLabels = True

		Dim linePanel = builder.CreateAndAddPlotWithBottomAndLeftAxes(linePlot, linePlotXRenderer, linePlotYRenderer)

		Dim stc = New Series2D(New List(Of Double)() From { _
		 37, _
		 8, _
		 55 _
		}, Nothing, New List(Of String)() From { _
		 "Smartphones", _
		 "Tablets", _
		 "Computers" _
		})

		' create a gauge
		Dim ovalGauge As New OvalGaugeRenderer()
		ovalGauge.Background = New MindFusion.Drawing.LinearGradientBrush(Color.White, Color.Gray)
		ovalGauge.PointerStroke = New SolidBrush(Color.Black)
		ovalGauge.PointerBackground = New SolidBrush(Color.Transparent)
		ovalGauge.TickBackground = New MindFusion.Drawing.LinearGradientBrush(Color.FromArgb(90, 121, 165), Color.FromArgb(0, 52, 102))

		Dim scale = ovalGauge.Gauge.Scales(0)
		scale.EndAngle = 270
		scale.StartAngle = 90
		scale.MinValue = 0
		scale.MaxValue = 10

		' gauge definition
		scale.ScaleChildren.Add(New Text() With { _
		  .Content = "TB/h" & vbLf & " x 1000", _
		  .FontFamily = "Verdana", _
		  .FontSize = New Length(12.0F, MindFusion.Gauges.LengthType.Relative), _
		  .FontStyle = FontStyle.Bold, _
		  .Alignment = StringAlignment.Far, _
		  .LineAlignment = StringAlignment.Far, _
		  .Foreground = Color.White, _
		  .Margin = New Thickness(0.3F, 0.3F, 0.3F, 0.3F) _
		})
		scale.Pointers.Add(New Pointer() With {
		  .Value = 1.8F,
		  .Fill = New SolidBrush(Color.FromArgb(90, 121, 165))
		})
		scale.Pointers.Add(New Pointer() With {
		  .Value = 4.63F,
		  .Fill = New SolidBrush(Color.FromArgb(206, 0, 0))
		})

		Dim ptr = scale.Pointers(0)
		ptr.IsInteractive = False
		ptr.Value = 7.3F
		ptr.Fill = New SolidBrush(Color.FromArgb(156, 170, 198))

		scale.MiddleTickSettings.ShowLabels = False


		Dim pnlGrid = New MindFusion.Charting.Components.GridPanel()
		For i As Integer = 0 To 0
			pnlGrid.Columns.Add(New GridColumn())
		Next
		pnlGrid.Rows.Add(New GridRow())

		For Each col As GridColumn In pnlGrid.Columns
			col.LengthType = MindFusion.Charting.Components.LengthType.Relative
		Next

		barPlot.SeriesRenderers.Add(barRenderer)
		linePlot.SeriesRenderers.Add(lineRenderer)

		Dim barPlotWithAxes = builder.CreatePlotWithBottomAndLeftAxes(barPlot, barPlotXAxisRenderer, barPlotYAxisRenderer)

		Dim barText = New TextComponent() With { _
		  .GridRow = 0, _
		  .GridColumn = 0, _
		  .Text = "Device usage during the day", _
		  .HorizontalAlignment = LayoutAlignment.Stretch _
		}

		Dim gaugeTitle = New TextComponent() With { _
		  .GridRow = 0, _
		  .GridColumn = 1, _
		  .Text = "Data per hour", _
		  .HorizontalAlignment = LayoutAlignment.Stretch _
		}

		barPlotWithAxes.GridRow = 1
		barPlotWithAxes.GridColumn = 0
		ovalGauge.GridColumn = 1
		ovalGauge.GridRow = 1

		pnlGrid.Children.Add(barText)
		pnlGrid.Children.Add(gaugeTitle)
		pnlGrid.Children.Add(barPlotWithAxes)
		pnlGrid.Children.Add(ovalGauge)

		' create a legend
		Dim legend = New LegendRenderer() With {
		  .Content = New ObservableCollection(Of SeriesRenderer)() From {
		  lineRenderer,
		  barRenderer
		 },
		  .Background = New SolidBrush(Color.White),
		  .HorizontalAlignment = LayoutAlignment.Far
		}
		dashboard.RootPanel.Children.Add(legend)
		dashboard.LayoutPanel.Children.Add(pnlGrid)

	End Sub

	Private Function GenerateSeries(startX As Integer, endX As Integer, intervalX As Integer) As Series2D
		Dim x As IList(Of Double) = New List(Of Double)()
		Dim y As IList(Of Double) = New List(Of Double)()
		Dim innerLabels As IList(Of String) = New List(Of String)()
		Dim i As Integer = startX
		While i <= endX
			x.Add(i)
			y.Add(rand.NextDouble() * 1000)
			i += intervalX
		End While
		Dim result = New Series2D(x, y, Nothing)
		Return result
	End Function

	Private Function AddToStack(stack As StackPanel, text As String, brush As Brush) As TextComponent
		Dim component = New TextComponent() With { _
		  .Text = text, _
		  .TextBrush = brush _
		}
		stack.Children.Add(component)
		Return component
	End Function

	Private rand As New Random()


End Class
